//
//  GCLoactionServiceManager.m
//  FengDu
//
//  Created by XC0621 on 2016/12/15.
//  Copyright © 2016年 Bge. All rights reserved.
//

#import "GCLoactionServiceManager.h"
#import <BaiduMapAPI_Map/BMKMapComponent.h>
#import <BaiduMapAPI_Location/BMKLocationComponent.h>
#import <BaiduMapAPI_Search/BMKSearchComponent.h>

@interface GCLoactionServiceManager () <BMKLocationServiceDelegate,UIAlertViewDelegate>

@property (copy, nonatomic) void (^SuccessBlock)(float locationlat,float locationlong);
@property (copy, nonatomic) void (^ErrorBlock)(NSUInteger errorCode);
@property (assign, nonatomic) int status;
@property (strong, nonatomic) BMKLocationService* locationService;

@end


@implementation GCLoactionServiceManager
static GCLoactionServiceManager *singleton;
+ (nonnull instancetype)sharedInstance {
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        singleton = [[[self class] alloc] init];
    });
    return singleton;
}

- (void) initGcLocationServiceManager {
    self.locationService = [[BMKLocationService alloc] init];
    self.locationService.delegate = self;
    self.status =  [CLLocationManager authorizationStatus];//定位权限
}

- (void)startLocationService {
    [self.locationService startUserLocationService];
}

- (void)getLoctionServiceWithLocationSuccess:(nullable LocationServiceSuccess)success
                                      Error:(nullable LocationServiceError)error {
    if (self.status < LocationSuccess) {
        [self showAlertView];
    }else {
        [self.locationService startUserLocationService];
    }
    
    [self setSuccessBlock:^(float locationlat, float locationlong) {
        success(locationlat,locationlong);
    }];
    
    [self setErrorBlock:^(NSUInteger errorCode) {
        error(errorCode);
    }];
    
}

//用户位置更新
- (void)didUpdateBMKUserLocation:(BMKUserLocation *)userLocation {
    NSLog(@"didUpdateUserLocation lat %f,long %f",userLocation.location.coordinate.latitude,userLocation.location.coordinate.longitude);
    float locationlat = userLocation.location.coordinate.latitude;
    float locationlong = userLocation.location.coordinate.longitude;
    [self.locationService stopUserLocationService];
    //定位成功
    if (self.SuccessBlock) {
        self.SuccessBlock(locationlat,locationlong);
    }
}

//定位失败
- (void)didFailToLocateUserWithError:(NSError *)error {
    
}

- (void) showAlertView {
    UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:nil
                                                        message:@"无法定位到您所在的城市，请前去开启GPS定位"
                                                       delegate:self
                                              cancelButtonTitle:nil
                                              otherButtonTitles:@"取消",@"去设置", nil];
    [alertView show];
}


- (void)alertView:(UIAlertView *)alertView clickedButtonAtIndex:(NSInteger)buttonIndex {
    if (buttonIndex == 0){
        //取消
        if (self.ErrorBlock) {
            self.ErrorBlock(LocationCancel);
        }
    }
    else {
        //跳转
        [self pushToSettingController];
    }
}

- (void)pushToSettingController {
    //打开设置页面，去设置定位
    NSURL *url = [NSURL URLWithString:UIApplicationOpenSettingsURLString];
    if ([[UIApplication sharedApplication] canOpenURL:url]) {
        [[UIApplication sharedApplication] openURL:url];
    }
}


@end
